Index: /anuga_core/source/anuga/shallow_water/shallow_water_domain.py
===================================================================
--- /anuga_core/source/anuga/shallow_water/shallow_water_domain.py	(revision 4630)
+++ /anuga_core/source/anuga/shallow_water/shallow_water_domain.py	(revision 4631)
@@ -100,5 +100,5 @@
 from anuga.config import minimum_allowed_height, maximum_allowed_speed
 from anuga.config import g, beta_h, beta_w, beta_w_dry,\
-     beta_uh, beta_uh_dry, beta_vh, beta_vh_dry, limit2007
+     beta_uh, beta_uh_dry, beta_vh, beta_vh_dry, tight_slope_limiters
 from anuga.config import alpha_balance
 
@@ -163,5 +163,5 @@
         self.alpha_balance = alpha_balance
 
-        self.limit2007 = limit2007
+        self.tight_slope_limiters = tight_slope_limiters
 
         self.flux_function = flux_function_central
@@ -232,5 +232,5 @@
 
         #FIXME (Ole): rename H0 to minimum_allowed_height_in_flux_computation
-        #rename limit2007 to tight_slope_limiters.
+        #rename tight_slope_limiters to tight_slope_limiters.
         #Maybe use histogram to identify isolated extreme speeds and deal with them adaptively
         #similarly to how we used to use 1 order steps to recover.
Index: /anuga_core/source/anuga/shallow_water/shallow_water_ext.c
===================================================================
--- /anuga_core/source/anuga/shallow_water/shallow_water_ext.c	(revision 4630)
+++ /anuga_core/source/anuga/shallow_water/shallow_water_ext.c	(revision 4631)
@@ -428,5 +428,5 @@
 			      double* ymomv,
 			      double H0,
-			      int limit2007,
+			      int tight_slope_limiters,
 			      double alpha_balance) {
 
@@ -451,5 +451,5 @@
     hmin = hv[k3];
     for (i=0; i<3; i++) {
-      if (limit2007 == 0) { 
+      if (tight_slope_limiters == 0) { 
         dz = max(dz, fabs(zv[k3+i]-zc[k]));
       }
@@ -464,5 +464,5 @@
     
     
-    if (limit2007 == 0) {     
+    if (tight_slope_limiters == 0) {     
       //If hmin > dz/alpha_balance then alpha = 1 and the bed will have no 
       //effect
@@ -1639,5 +1639,5 @@
   double H0;
 
-  int N, limit2007; //, err;
+  int N, tight_slope_limiters; //, err;
 
   // Convert Python arguments to C
@@ -1670,10 +1670,10 @@
 
   
-  Tmp = PyObject_GetAttrString(domain, "limit2007");
+  Tmp = PyObject_GetAttrString(domain, "tight_slope_limiters");
   if (!Tmp) {
-    PyErr_SetString(PyExc_RuntimeError, "shallow_water_ext.c: balance_deep_and_shallow could not obtain object limit2007 from domain");
+    PyErr_SetString(PyExc_RuntimeError, "shallow_water_ext.c: balance_deep_and_shallow could not obtain object tight_slope_limiters from domain");
     return NULL;
   }  
-  limit2007 = PyInt_AsLong(Tmp);
+  tight_slope_limiters = PyInt_AsLong(Tmp);
   Py_DECREF(Tmp);
     
@@ -1696,5 +1696,5 @@
 			    (double*) ymomv -> data,
 			    H0,
-			    (int) limit2007,
+			    (int) tight_slope_limiters,
 			    alpha_balance);
 
Index: /anuga_core/source/anuga/shallow_water/test_data_manager.py
===================================================================
--- /anuga_core/source/anuga/shallow_water/test_data_manager.py	(revision 4630)
+++ /anuga_core/source/anuga/shallow_water/test_data_manager.py	(revision 4631)
@@ -355,5 +355,5 @@
         sww.store_connectivity()
         sww.store_timestep('stage')
-        #self.domain.limit2007 = 1
+        #self.domain.tight_slope_limiters = 1
         self.domain.evolve_to_end(finaltime = 0.01)
         sww.store_timestep('stage')
@@ -412,5 +412,5 @@
         sww.store_connectivity()
         sww.store_timestep('stage')
-        #self.domain.limit2007 = 1
+        #self.domain.tight_slope_limiters = 1
         self.domain.evolve_to_end(finaltime = 0.01)
         sww.store_timestep('stage')
@@ -464,5 +464,5 @@
         self.domain.store = True
         self.domain.beta_h = 0
-        #self.domain.limit2007 = 1
+        #self.domain.tight_slope_limiters = 1
 
         #Evolution
@@ -507,5 +507,5 @@
         sww.store_timestep('stage')
 
-        #self.domain.limit2007 = 1
+        #self.domain.tight_slope_limiters = 1
         self.domain.evolve_to_end(finaltime = 0.01)
         sww.store_timestep('stage')
@@ -1137,5 +1137,5 @@
         sww.store_timestep('stage')
 
-        #self.domain.limit2007 = 1
+        #self.domain.tight_slope_limiters = 1
 
         self.domain.evolve_to_end(finaltime = 0.01)
@@ -1851,5 +1851,5 @@
         sww.store_timestep('stage')
         
-        domain.limit2007 = 1
+        domain.tight_slope_limiters = 1
         domain.evolve_to_end(finaltime = 0.01)
         sww.store_timestep('stage')
@@ -2037,5 +2037,5 @@
         sww.store_timestep('stage')
 
-        #domain.limit2007 = 1
+        #domain.tight_slope_limiters = 1
         domain.evolve_to_end(finaltime = 0.01)
         sww.store_timestep('stage')
@@ -2186,5 +2186,5 @@
         sww.store_timestep('stage')
 
-        #self.domain.limit2007 = 1
+        #self.domain.tight_slope_limiters = 1
         self.domain.evolve_to_end(finaltime = 0.01)
         sww.store_timestep('stage')
@@ -2298,5 +2298,5 @@
         sww.store_timestep('stage')
 
-        #self.domain.limit2007 = 1
+        #self.domain.tight_slope_limiters = 1
         self.domain.evolve_to_end(finaltime = 0.01)
         sww.store_timestep('stage')
@@ -2557,5 +2557,5 @@
         sww.store_timestep('stage')
 
-        #self.domain.limit2007 = 1
+        #self.domain.tight_slope_limiters = 1
         self.domain.evolve_to_end(finaltime = 0.01)
         sww.store_timestep('stage')
@@ -2657,5 +2657,5 @@
         sww.store_timestep('stage')
 
-        #self.domain.limit2007 = 1
+        #self.domain.tight_slope_limiters = 1
         self.domain.evolve_to_end(finaltime = 0.01)
         sww.store_timestep('stage')
@@ -3409,5 +3409,5 @@
         self.domain.reduction = mean
         self.domain.set_datadir('.')
-        #self.domain.limit2007 = 1        
+        #self.domain.tight_slope_limiters = 1        
 
 
@@ -3481,5 +3481,5 @@
         domain.check_integrity()
         #Evolution
-        #domain.limit2007 = 1
+        #domain.tight_slope_limiters = 1
         for t in domain.evolve(yieldstep = yiel, finaltime = 0.05):
             #domain.write_time()
Index: /anuga_core/source/anuga/shallow_water/test_shallow_water_domain.py
===================================================================
--- /anuga_core/source/anuga/shallow_water/test_shallow_water_domain.py	(revision 4630)
+++ /anuga_core/source/anuga/shallow_water/test_shallow_water_domain.py	(revision 4631)
@@ -976,5 +976,5 @@
         domain = Domain(points, vertices, boundary)
         domain.set_name('runup_test')
-        #domain.limit2007 = 1 #FIXME: This works better with old limiters
+        #domain.tight_slope_limiters = 1 #FIXME: This works better with old limiters
 
         #--------------------------------------------------------------
@@ -1169,5 +1169,5 @@
         
         # FIXME (Ole): Need tests where this is commented out
-        domain.limit2007 = 0 # Backwards compatibility (14/4/7)                 
+        domain.tight_slope_limiters = 0 # Backwards compatibility (14/4/7)                 
         domain.H0 = 0 # Backwards compatibility (6/2/7)
         domain.beta_h = 0.2 # Backwards compatibility (14/2/7)
@@ -2084,5 +2084,5 @@
         domain._order_ = 1
         
-        domain.limit2007 = 0
+        domain.tight_slope_limiters = 0
         domain.distribute_to_vertices_and_edges()
         assert allclose(L[1], [0.1, 20.1, 20.1])
@@ -2090,5 +2090,5 @@
             assert allclose(volumes[i], sum(L[i])/3)                    
         
-        domain.limit2007 = 1 # Allow triangle to be flatter (closer to bed)
+        domain.tight_slope_limiters = 1 # Allow triangle to be flatter (closer to bed)
         domain.distribute_to_vertices_and_edges()
         assert allclose(L[1], [0.298, 20.001, 20.001])
@@ -2098,5 +2098,5 @@
         domain._order_ = 2
         
-        domain.limit2007 = 0
+        domain.tight_slope_limiters = 0
         domain.distribute_to_vertices_and_edges()
         assert allclose(L[1], [0.1, 20.1, 20.1])        
@@ -2104,5 +2104,5 @@
             assert allclose(volumes[i], sum(L[i])/3)            
         
-        domain.limit2007 = 1 # Allow triangle to be flatter (closer to bed)
+        domain.tight_slope_limiters = 1 # Allow triangle to be flatter (closer to bed)
         domain.distribute_to_vertices_and_edges()
         assert allclose(L[1], [0.298, 20.001, 20.001])
@@ -2154,5 +2154,5 @@
         domain._order_ = 1
         
-        domain.limit2007 = 0
+        domain.tight_slope_limiters = 0
         domain.distribute_to_vertices_and_edges()
         assert allclose(L[1], [4.1, 16.1, 20.1])        
@@ -2161,5 +2161,5 @@
         
                 
-        domain.limit2007 = 1 # Allow triangle to be flatter (closer to bed)
+        domain.tight_slope_limiters = 1 # Allow triangle to be flatter (closer to bed)
         domain.distribute_to_vertices_and_edges()
         assert allclose(L[1], [4.2386, 16.0604, 20.001])
@@ -2170,5 +2170,5 @@
         domain._order_ = 2
         
-        domain.limit2007 = 0    
+        domain.tight_slope_limiters = 0    
         domain.distribute_to_vertices_and_edges()
         assert allclose(L[1], [4.1, 16.1, 20.1])
@@ -2176,5 +2176,5 @@
             assert allclose(volumes[i], sum(L[i])/3)    
         
-        domain.limit2007 = 1 # Allow triangle to be flatter (closer to bed)
+        domain.tight_slope_limiters = 1 # Allow triangle to be flatter (closer to bed)
         domain.distribute_to_vertices_and_edges()
         assert allclose(L[1], [4.23370103, 16.06529897, 20.001])
@@ -2234,5 +2234,5 @@
         
         # FIXME (Ole): Need tests where this is commented out
-        domain.limit2007 = 0 # Backwards compatibility (14/4/7)                 
+        domain.tight_slope_limiters = 0 # Backwards compatibility (14/4/7)                 
         
                 
@@ -2320,5 +2320,5 @@
 
         #Also check that Python and C version produce the same
-        # No longer applicable if limit2007 == 1
+        # No longer applicable if tight_slope_limiters == 1
         #print stage.vertex_values
         #assert allclose (stage.vertex_values,
@@ -3176,5 +3176,5 @@
         # FIXME (Ole): Need tests where these two are commented out
         domain.H0 = 0        # Backwards compatibility (6/2/7)        
-        domain.limit2007 = 0 # Backwards compatibility (14/4/7)         
+        domain.tight_slope_limiters = 0 # Backwards compatibility (14/4/7)         
 
         #Bed-slope and friction
@@ -3248,5 +3248,5 @@
         
         # FIXME (Ole): Need tests where this is commented out
-        domain.limit2007 = 0 # Backwards compatibility (14/4/7)         
+        domain.tight_slope_limiters = 0 # Backwards compatibility (14/4/7)         
         
         #Bed-slope and friction at vertices (and interpolated elsewhere)
@@ -3344,5 +3344,5 @@
         
         # FIXME (Ole): Need tests where this is commented out
-        domain.limit2007 = 0 # Backwards compatibility (14/4/7)                 
+        domain.tight_slope_limiters = 0 # Backwards compatibility (14/4/7)                 
         domain.H0 = 0 # Backwards compatibility (6/2/7)        
 
@@ -3446,5 +3446,5 @@
         
         # FIXME (Ole): Need tests where this is commented out
-        domain.limit2007 = 0 # Backwards compatibility (14/4/7)                 
+        domain.tight_slope_limiters = 0 # Backwards compatibility (14/4/7)                 
         domain.H0 = 0 # Backwards compatibility (6/2/7)
 
@@ -3546,5 +3546,5 @@
         # FIXME (Ole): Need tests where these two are commented out
         domain.H0 = 0        # Backwards compatibility (6/2/7)        
-        domain.limit2007 = 0 # Backwards compatibility (14/4/7)                 
+        domain.tight_slope_limiters = 0 # Backwards compatibility (14/4/7)                 
         
                 
@@ -3678,5 +3678,5 @@
         domain.beta_h = 0.0 #Use first order in h-limiter
         domain.H0 = 0.001
-        domain.limit2007 = 1
+        domain.tight_slope_limiters = 1
 
         #Bed-slope and friction at vertices (and interpolated elsewhere)
@@ -3806,5 +3806,5 @@
         # FIXME (Ole): Need tests where these two are commented out
         domain.H0 = 0        # Backwards compatibility (6/2/7)        
-        domain.limit2007 = 0 # Backwards compatibility (14/4/7)                         
+        domain.tight_slope_limiters = 0 # Backwards compatibility (14/4/7)                         
         
 
@@ -4537,5 +4537,5 @@
         domain = Domain(points, vertices, boundary)
         domain.default_order = 2
-        domain.limit2007 = 1
+        domain.tight_slope_limiters = 1
         domain.H0 = 0.01
         
Index: /anuga_validation/automated_validation_tests/okushiri_tank_validation/run_okushiri.py
===================================================================
--- /anuga_validation/automated_validation_tests/okushiri_tank_validation/run_okushiri.py	(revision 4630)
+++ /anuga_validation/automated_validation_tests/okushiri_tank_validation/run_okushiri.py	(revision 4631)
@@ -61,5 +61,5 @@
 # (this in planned to be the default!)
 domain.beta_h = 0.0
-domain.limit2007 = 1 # Run time invariant in this case
+domain.tight_slope_limiters = 1 # Run time invariant in this case
 
 #-------------------------
Index: /anuga_validation/okushiri_2005/run_okushiri.py
===================================================================
--- /anuga_validation/okushiri_2005/run_okushiri.py	(revision 4630)
+++ /anuga_validation/okushiri_2005/run_okushiri.py	(revision 4631)
@@ -57,11 +57,11 @@
 domain.set_minimum_storable_height(0.001) # Don't store w < 0.001m
 domain.set_maximum_allowed_speed(0.1)     # Allow a little runoff (0.1 is OK)
-domain.limit2007 = 1
+domain.tight_slope_limiters = 1
 domain.beta_h = 0.0
 
 #Timings on AMD64-242 (beta_h=0)
-#  limit2007 = 0:
+#  tight_slope_limiters = 0:
 #    3035s - 3110s
-#  limit2007 = 1:
+#  tight_slope_limiters = 1:
 #    3000s - 3008s
 #
Index: /anuga_validation/performance_tests/okushiri/run_okushiri_profile.py
===================================================================
--- /anuga_validation/performance_tests/okushiri/run_okushiri_profile.py	(revision 4630)
+++ /anuga_validation/performance_tests/okushiri/run_okushiri_profile.py	(revision 4631)
@@ -63,5 +63,5 @@
 # (this in planned to be the default!)
 domain.beta_h = 0.0
-domain.limit2007 = 1 # Run time invariant in this case
+domain.tight_slope_limiters = 1 # Run time invariant in this case
 
 #-------------------------
Index: /anuga_validation/solitary_waves/solitary_wave_runup.py
===================================================================
--- /anuga_validation/solitary_waves/solitary_wave_runup.py	(revision 4630)
+++ /anuga_validation/solitary_waves/solitary_wave_runup.py	(revision 4631)
@@ -87,5 +87,5 @@
 #domain.set_minimum_allowed_height(0.01)
 domain.beta_h = 0.0
-domain.limit2007 = 1
+domain.tight_slope_limiters = 1
 domain.set_name(simulation_name)
 
Index: /anuga_work/development/Rudy_vandrie_2007/run_example.py
===================================================================
--- /anuga_work/development/Rudy_vandrie_2007/run_example.py	(revision 4630)
+++ /anuga_work/development/Rudy_vandrie_2007/run_example.py	(revision 4631)
@@ -61,5 +61,5 @@
 # (this in planned to be the default!)
 domain.beta_h = 0.0
-domain.limit2007 = 0
+domain.tight_slope_limiters = 0
 
 #-------------------------
Index: /anuga_work/development/Rudy_vandrie_2007/run_hydro_example.py
===================================================================
--- /anuga_work/development/Rudy_vandrie_2007/run_hydro_example.py	(revision 4630)
+++ /anuga_work/development/Rudy_vandrie_2007/run_hydro_example.py	(revision 4631)
@@ -31,5 +31,5 @@
 domain.set_minimum_storable_height(0.0001)
 domain.beta_h = 0.0
-domain.limit2007 = 1
+domain.tight_slope_limiters = 1
 
 
Index: /anuga_work/development/dam_test_from_brad_2007/dam_sample.py
===================================================================
--- /anuga_work/development/dam_test_from_brad_2007/dam_sample.py	(revision 4630)
+++ /anuga_work/development/dam_test_from_brad_2007/dam_sample.py	(revision 4631)
@@ -30,5 +30,5 @@
 #domain.set_store_vertices_uniquely(True)      # Look at the 'real' triangles
 domain.beta_h = 0.0
-domain.limit2007 = 1
+domain.tight_slope_limiters = 1
 domain.set_minimum_allowed_height(0.01)
 
Index: /anuga_work/development/demos/island.py
===================================================================
--- /anuga_work/development/demos/island.py	(revision 4630)
+++ /anuga_work/development/demos/island.py	(revision 4631)
@@ -64,5 +64,5 @@
 
 domain.beta_h     = 0.0
-domain.limit2007 = 1
+domain.tight_slope_limiters = 1
 
 #------------------------------------------------------------------------------
Index: /anuga_work/development/demos/limiter_test.py
===================================================================
--- /anuga_work/development/demos/limiter_test.py	(revision 4630)
+++ /anuga_work/development/demos/limiter_test.py	(revision 4631)
@@ -27,5 +27,5 @@
 domain.set_store_vertices_uniquely(True)
 domain.set_default_order(2)
-domain.limit2007 = 1
+domain.tight_slope_limiters = 1
 
 #------------------------------------------------------------------------------
Index: /anuga_work/production/broome_2006/run_broome_urs.py
===================================================================
--- /anuga_work/production/broome_2006/run_broome_urs.py	(revision 4630)
+++ /anuga_work/production/broome_2006/run_broome_urs.py	(revision 4631)
@@ -174,5 +174,5 @@
     print 'domain id', id(domain)
     domain.beta_h = 0
-    #domain.limit2007 = 1
+    #domain.tight_slope_limiters = 1
 
     #-------------------------------------------------------------------------
Index: /anuga_work/production/dampier_2006/run_dampier.py
===================================================================
--- /anuga_work/production/dampier_2006/run_dampier.py	(revision 4630)
+++ /anuga_work/production/dampier_2006/run_dampier.py	(revision 4631)
@@ -160,5 +160,5 @@
 print 'domain id', id(domain)
 domain.beta_h = 0
-#domain.limit2007 = 1
+#domain.tight_slope_limiters = 1
 
 #-------------------------------------------------------------------------
Index: /anuga_work/production/dampier_2006/run_dampier_simple.py
===================================================================
--- /anuga_work/production/dampier_2006/run_dampier_simple.py	(revision 4630)
+++ /anuga_work/production/dampier_2006/run_dampier_simple.py	(revision 4631)
@@ -233,5 +233,5 @@
 print 'domain id', id(domain)
 domain.beta_h = 0
-domain.limit2007 = 1
+domain.tight_slope_limiters = 1
 '''
 #-------------------------------------------------------------------------
Index: /anuga_work/production/dampier_2006/run_dampier_urs.py
===================================================================
--- /anuga_work/production/dampier_2006/run_dampier_urs.py	(revision 4630)
+++ /anuga_work/production/dampier_2006/run_dampier_urs.py	(revision 4631)
@@ -169,5 +169,5 @@
     print 'domain id', id(domain)
     domain.beta_h = 0
-    #domain.limit2007 = 1
+    #domain.tight_slope_limiters = 1
 
     #-------------------------------------------------------------------------
Index: /anuga_work/production/exmouth_2006/run_exmouth.py
===================================================================
--- /anuga_work/production/exmouth_2006/run_exmouth.py	(revision 4630)
+++ /anuga_work/production/exmouth_2006/run_exmouth.py	(revision 4631)
@@ -170,5 +170,5 @@
     domain.beta_h = 0 #sets the surface of the triangle to follow the bathy
     #domain.H0=0.01 #controls the flux limiter (limiter2007)
-    #domain.limit2007 = 1 #minimises creep
+    #domain.tight_slope_limiters = 1 #minimises creep
 
     #-------------------------------------------------------------------------
Index: /anuga_work/production/onslow_2006/run_onslow_urs.py
===================================================================
--- /anuga_work/production/onslow_2006/run_onslow_urs.py	(revision 4630)
+++ /anuga_work/production/onslow_2006/run_onslow_urs.py	(revision 4631)
@@ -170,5 +170,5 @@
     domain.beta_h = 0 #sets the surface of the triangle to follow the bathy
     #domain.H0=0.01 #controls the flux limiter (limiter2007)
-    #domain.limit2007 = 1 #minimises creep
+    #domain.tight_slope_limiters = 1 #minimises creep
 
     #-------------------------------------------------------------------------
Index: /anuga_work/production/onslow_2006/ticket160_run.py
===================================================================
--- /anuga_work/production/onslow_2006/ticket160_run.py	(revision 4630)
+++ /anuga_work/production/onslow_2006/ticket160_run.py	(revision 4631)
@@ -182,5 +182,5 @@
     domain.set_maximum_allowed_speed(0.1) # Allow a little runoff (0.1 is OK)
     domain.beta_h = 0
-    domain.limit2007 = 1
+    domain.tight_slope_limiters = 1
     domain.H0=0.01
 
Index: /anuga_work/production/pt_hedland_2006/run_pt_hedland_urs.py
===================================================================
--- /anuga_work/production/pt_hedland_2006/run_pt_hedland_urs.py	(revision 4630)
+++ /anuga_work/production/pt_hedland_2006/run_pt_hedland_urs.py	(revision 4631)
@@ -162,5 +162,5 @@
     domain.beta_h = 0 #sets the surface of the triangle to follow the bathy
     #domain.H0=0.01 #controls the flux limiter (limiter2007)
-    #domain.limit2007 = 1 #minimises creep
+    #domain.tight_slope_limiters = 1 #minimises creep
 
     #-------------------------------------------------------------------------
Index: /anuga_work/production/shark_bay_2007/run_shark_bay.py
===================================================================
--- /anuga_work/production/shark_bay_2007/run_shark_bay.py	(revision 4630)
+++ /anuga_work/production/shark_bay_2007/run_shark_bay.py	(revision 4631)
@@ -170,5 +170,5 @@
     print 'domain id', id(domain)
     domain.beta_h = 0
-    #domain.limit2007 = 1
+    #domain.tight_slope_limiters = 1
     
 
Index: /anuga_work/production/shark_bay_2007/run_shark_bay_frequency_sweep.py
===================================================================
--- /anuga_work/production/shark_bay_2007/run_shark_bay_frequency_sweep.py	(revision 4630)
+++ /anuga_work/production/shark_bay_2007/run_shark_bay_frequency_sweep.py	(revision 4631)
@@ -162,5 +162,5 @@
     print 'domain id', id(domain)
     domain.beta_h = 0
-    #domain.limit2007 = 1
+    #domain.tight_slope_limiters = 1
     
 

Index: /anuga_core/source/anuga/config.py
===================================================================
--- /anuga_core/source/anuga/config.py	(revision 4630)
+++ /anuga_core/source/anuga/config.py	(revision 4631)
@@ -81,5 +81,5 @@
 beta_h      = 0.2
 
 # beta_h can be safely put to zero esp if we are using limit2007 = 1. This will
 # also speed things up.
 beta_h = 0.0
@@ -94,7 +94,7 @@
 
 # Flag use of new limiters.
-# limit2007 = 0 means use old limiters (e.g. for some tests)
-# limit2007 = 1 means use new limiters that hug the bathymetry closer
-limit2007 = 0
+# tight_slope_limiters = 0 means use old limiters (e.g. for some tests)
+# tight_slope_limiters = 1 means use new limiters that hug the bathymetry closer
+tight_slope_limiters = 0
 
 
@@ -81,5 +81,5 @@
 beta_h      = 0.2
 
-# beta_h can be safely put to zero esp if we are using limit2007 = 1. This will
+# beta_h can be safely put to zero esp if we are using tight_slope_limiters = 1. This will
 # also speed things up.
 beta_h = 0.0